From 228df8742bfd755ee2b1b699d235270f77d64538 Mon Sep 17 00:00:00 2001
From: Daniel Gustafsson <daniel@yesql.se>
Date: Fri, 14 Jun 2019 12:38:11 +0200
Subject: [PATCH] doc: Add missing members to SPITupleTable documentation

Commit 3d13623d75d3206c8f009353415043a191ebab39 added the next and
subid fields to the SPITupleTable struct, but they never made it
into the documentation. While these are internal members, we already
document several other internal ones so add these too to make the
documentation match reality.

Since this makes the number of internal members far outnumber the
public ones, also reword the statement about which fields can be
used to improve clarity.
---
 doc/src/sgml/spi.sgml | 8 +++++---
 1 file changed, 5 insertions(+), 3 deletions(-)

diff --git a/doc/src/sgml/spi.sgml b/doc/src/sgml/spi.sgml
index 66eced6c94..cd6dd1c5f0 100644
--- a/doc/src/sgml/spi.sgml
+++ b/doc/src/sgml/spi.sgml
@@ -325,14 +325,16 @@ typedef struct
     uint64      free;           /* number of free vals */
     TupleDesc   tupdesc;        /* row descriptor */
     HeapTuple  *vals;           /* rows */
+    slist_node  next;           /* link for internal bookkeeping */
+    SubTransactionId subid;     /* subxact in which tuptable was created */
 } SPITupleTable;
 </programlisting>
+   <structfield>vals</structfield> and <structfield>tupdesc</structfield> can
+   be used by SPI callers, the remaining fields are internal.
    <structfield>vals</structfield> is an array of pointers to rows.  (The number
    of valid entries is given by <varname>SPI_processed</varname>.)
    <structfield>tupdesc</structfield> is a row descriptor which you can pass to
-   SPI functions dealing with rows.  <structfield>tuptabcxt</structfield>,
-   <structfield>alloced</structfield>, and <structfield>free</structfield> are internal
-   fields not intended for use by SPI callers.
+   SPI functions dealing with rows.
   </para>
 
   <para>
-- 
2.14.1.145.gb3622a4ee

